@@ -1,12 +1,17 @@
 #!/usr/bin/python3
 
 import pytest
-import nx5d.h5like.petra3 as p3
+import nx5d.h5like.fio as p3
 
 @pytest.fixture
 def fio_file():
     return 'tests/test_data/fioh5/m3_2507_00744.fio'
 
+
+@pytest.fixture
+def fio_tiff():
+    return 'tests/test_data/fiotiff/s1_1161_00484.fio'
+
 def test_fio_parser(fio_file):
     ''' Reading/parsing a FIO file '''
     
@@ -44,3 +49,16 @@ def test_fio_loadh5(fio_file):
     assert data.shape == (61, 100, 100)
 
     assert data.shape[0] == fh['fio/data/om'].shape[0]
+
+
+def test_fio_loadtiff(fio_tiff):
+    
+    f5 = p3.FioTiff(fio_tiff, 'fio')
+
+    # This is where we store the TIFF dataset
+    assert "fio" in f5
+    assert "p100k" in f5['fio']
+    assert len(f5["fio/p100k/data"].shape) == 3
+
+    # This is real data, sum is somewhere around 25k or so.
+    assert f5["fio/p100k/data"][0:2,...].sum() > 0
