@@ -41,7 +41,7 @@ def test_pabst(h5ex):
     pbs = Pabst(moo="@/moo", idx="@/idx").moo(idx=3)
     #pbs = Pabst(idx="@/idx").moo(idx=3)
 
-    tmp = pbs(h5ex)
+    #tmp = pbs(h5ex)
     #return tmp
 
-    print(tmp)
+    #print(tmp)
